@@ -76,6 +76,7 @@
 #include <gio/goutputstream.h>
 #include <gio/gresolver.h>
 #include <gio/gseekable.h>
+#include <gio/gsettings.h>
 #include <gio/gsimpleasyncresult.h>
 #include <gio/gsocket.h>
 #include <gio/gsocketaddress.h>
@@ -90,7 +91,6 @@
 #include <gio/gthreadedsocketservice.h>
 #include <gio/gsrvtarget.h>
 #include <gio/gthemedicon.h>
-#include <gio/gutf8inputstream.h>
 #include <gio/gvfs.h>
 #include <gio/gvolume.h>
 #include <gio/gvolumemonitor.h>
