@@ -59,7 +59,7 @@ typedef enum {
 typedef enum {
   G_CONVERTER_NO_FLAGS     = 0,         /*< nick=none >*/
   G_CONVERTER_INPUT_AT_END = (1 << 0),  /*< nick=input-at-end >*/
-  G_CONVERTER_FLUSH        = (1 << 1),  /*< nick=flush >*/
+  G_CONVERTER_FLUSH        = (1 << 1)   /*< nick=flush >*/
 } GConverterFlags;
 
 /**
@@ -74,10 +74,10 @@ typedef enum {
  * Since: 2.24
  */
 typedef enum {
-  G_CONVERTER_ERROR     = 0, /*< nick=error >*/
+  G_CONVERTER_ERROR     = 0,  /*< nick=error >*/
   G_CONVERTER_CONVERTED = 1,  /*< nick=converted >*/
   G_CONVERTER_FINISHED  = 2,  /*< nick=finished >*/
-  G_CONVERTER_FLUSHED   = 3,  /*< nick=flushed >*/
+  G_CONVERTER_FLUSHED   = 3   /*< nick=flushed >*/
 } GConverterResult;
 
 
@@ -301,12 +301,18 @@ typedef enum {
  * GFileMonitorFlags:
  * @G_FILE_MONITOR_NONE: No flags set.
  * @G_FILE_MONITOR_WATCH_MOUNTS: Watch for mount events.
+ * @G_FILE_MONITOR_SEND_MOVED: Pair DELETED and CREATED events caused
+ *   by file renames (moves) and send a single G_FILE_MONITOR_EVENT_MOVED
+ *   event instead (NB: not supported on all backends; the default
+ *   behaviour -without specifying this flag- is to send single DELETED
+ *   and CREATED events).
  *
  * Flags used to set what a #GFileMonitor will watch for.
  */
 typedef enum {
   G_FILE_MONITOR_NONE         = 0,
-  G_FILE_MONITOR_WATCH_MOUNTS = (1 << 0)
+  G_FILE_MONITOR_WATCH_MOUNTS = (1 << 0),
+  G_FILE_MONITOR_SEND_MOVED   = (1 << 1)
 } GFileMonitorFlags;
 
 
@@ -361,6 +367,7 @@ typedef enum {
  * @G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED: a file attribute was changed.
  * @G_FILE_MONITOR_EVENT_PRE_UNMOUNT: the file location will soon be unmounted.
  * @G_FILE_MONITOR_EVENT_UNMOUNTED: the file location was unmounted.
+ * @G_FILE_MONITOR_EVENT_MOVED: the file was moved.
  *
  * Specifies what type of event a monitor event is.
  **/
@@ -371,7 +378,8 @@ typedef enum {
   G_FILE_MONITOR_EVENT_CREATED,
   G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED,
   G_FILE_MONITOR_EVENT_PRE_UNMOUNT,
-  G_FILE_MONITOR_EVENT_UNMOUNTED
+  G_FILE_MONITOR_EVENT_UNMOUNTED,
+  G_FILE_MONITOR_EVENT_MOVED
 } GFileMonitorEvent;
 
 
@@ -690,6 +698,40 @@ typedef enum {
   G_ZLIB_COMPRESSOR_FORMAT_RAW
 } GZlibCompressorFormat;
 
+/**
+ * GUnixSocketAddressType:
+ * @G_UNIX_SOCKET_ADDRESS_INVALID: invalid
+ * @G_UNIX_SOCKET_ADDRESS_ANONYMOUS: anonymous
+ * @G_UNIX_SOCKET_ADDRESS_PATH: a filesystem path
+ * @G_UNIX_SOCKET_ADDRESS_ABSTRACT: an abstract name
+ * @G_UNIX_SOCKET_ADDRESS_ABSTRACT_PADDED: an abstract name, 0-padded
+ *   to the full length of a unix socket name
+ *
+ * The type of name used by a #GUnixSocketAddress.
+ * %G_UNIX_SOCKET_ADDRESS_PATH indicates a traditional unix domain
+ * socket bound to a filesystem path. %G_UNIX_SOCKET_ADDRESS_ANONYMOUS
+ * indicates a socket not bound to any name (eg, a client-side socket,
+ * or a socket created with socketpair()).
+ *
+ * For abstract sockets, there are two incompatible ways of naming
+ * them: the man pages suggest using the entire <literal>struct
+ * sockaddr_un</literal> as the name, padding the unused parts of the
+ * %sun_path field with zeroes; this corresponds to
+ * %G_UNIX_SOCKET_ADDRESS_ABSTRACT_PADDED. However, many programs
+ * instead just use a portion of %sun_path, and pass an appropriate
+ * smaller length to bind() or connect(). This is
+ * %G_UNIX_SOCKET_ADDRESS_ABSTRACT.
+ *
+ * Since: 2.26
+ */
+typedef enum {
+  G_UNIX_SOCKET_ADDRESS_INVALID,
+  G_UNIX_SOCKET_ADDRESS_ANONYMOUS,
+  G_UNIX_SOCKET_ADDRESS_PATH,
+  G_UNIX_SOCKET_ADDRESS_ABSTRACT,
+  G_UNIX_SOCKET_ADDRESS_ABSTRACT_PADDED
+} GUnixSocketAddressType;
+
 G_END_DECLS
 
 #endif /* __GIO_ENUMS_H__ */
