@@ -71,6 +71,8 @@ GType g_socket_protocol_get_type (void) G_GNUC_CONST;
 #define G_TYPE_SOCKET_PROTOCOL (g_socket_protocol_get_type ())
 GType g_zlib_compressor_format_get_type (void) G_GNUC_CONST;
 #define G_TYPE_ZLIB_COMPRESSOR_FORMAT (g_zlib_compressor_format_get_type ())
+GType g_unix_socket_address_type_get_type (void) G_GNUC_CONST;
+#define G_TYPE_UNIX_SOCKET_ADDRESS_TYPE (g_unix_socket_address_type_get_type ())
 
 /* enumerations from "gsettings.h" */
 GType g_settings_bind_flags_get_type (void) G_GNUC_CONST;
